# -*- coding:utf-8 -*-
import random
import time
class name():
    def getname(self):
        xing = '赵钱孙李周吴郑王冯陈褚卫蒋沈韩杨朱秦尤许何吕施张孔曹严华金魏陶姜戚谢邹喻柏水窦章云苏潘葛' \
            '奚范彭郎鲁韦昌马苗凤花方俞任袁柳酆鲍史唐费廉岑薛雷贺倪汤滕殷罗毕郝邬安常乐于时傅皮卞齐康' \
            '伍余元卜顾孟平黄和穆萧尹姚邵湛汪祁毛禹狄米贝明臧计伏成戴谈宋茅庞熊纪舒屈项祝董梁杜阮蓝闵' \
            '席季麻强贾路娄危江童颜郭梅盛林刁钟徐邱骆高夏蔡田樊胡凌霍虞万支柯昝管卢莫经房裘缪干解应宗' \
            '丁宣贲邓郁单杭洪包诸左石崔吉钮龚程嵇邢滑裴陆荣翁荀羊於惠甄曲家封芮羿储靳汲邴糜松井段富巫' \
            '乌焦巴弓牧隗山谷车侯宓蓬全郗班仰秋仲伊宫宁仇栾暴甘钭厉戎祖武符刘景詹束龙叶幸司韶郜黎蓟薄' \
            '印宿白怀蒲邰从鄂索咸籍赖卓蔺屠蒙池乔阴鬱胥能苍双闻莘党翟谭贡劳逄姬申扶堵冉宰郦雍卻璩桑桂' \
            '濮牛寿通边扈燕冀郏浦尚农温别庄晏柴瞿阎充慕连茹习宦艾鱼容向古易慎戈廖庾终暨居衡步都耿满弘' \
            '匡国文寇广禄阙东欧殳沃利蔚越夔隆师巩厍聂晁勾敖融冷訾辛阚那简饶空曾毋沙乜养鞠须丰巢关蒯相' \
            '查后荆红游竺权逯盖益桓公万俟司马上官欧阳夏侯诸葛闻人东方赫连皇甫尉迟公羊澹台公冶宗政濮阳' \
            '淳于单于太叔申屠公孙仲孙轩辕令狐钟离宇文长孙慕容鲜于闾丘司徒司空丌官司寇仉督子车颛孙端木' \
            '巫马公西漆雕乐正壤驷公良拓跋夹谷宰父谷梁晋楚闫法汝鄢涂钦段干百里东郭南门呼延归海羊舌微生' \
            '岳帅缑亢况郈有琴梁丘左丘东门西门商牟佘佴伯赏南宫墨哈谯笪年爱阳佟第五言福'
        ming = '伟刚勇毅俊峰强军平保东文辉力明永健世广志义兴良海山仁波宁贵福生龙元全国胜学祥才发武新利清' \
            '飞彬富顺信子杰涛昌成康星光天达安岩中茂进林有坚和彪博诚先敬震振壮会思群豪心邦承乐绍功松善' \
            '厚庆磊民友裕河哲江超浩亮政谦亨奇固之轮翰朗伯宏言若鸣朋斌梁栋维启克伦翔旭鹏泽晨辰士以建家' \
            '致树炎德行时泰盛秀娟英华慧巧美娜静淑惠珠翠雅芝玉萍红娥玲芬芳燕彩春菊兰凤洁梅琳素云莲真环' \
            '雪荣爱妹霞香月莺媛艳瑞凡佳嘉琼勤珍贞莉桂娣叶璧璐娅琦晶妍茜秋珊莎锦黛青倩婷姣婉娴瑾颖露瑶' \
            '怡婵雁蓓纨仪荷丹蓉眉君琴蕊薇菁梦岚苑筠柔竹霭凝晓欢霄枫芸菲寒欣滢伊亚宜可姬舒影荔枝思丽秀' \
            '飘育馥琦晶妍茜秋珊莎锦黛青倩婷宁蓓纨苑婕馨瑗琰韵融园艺咏卿聪澜纯毓悦昭冰爽琬茗羽希汗寒函'\
            '听风余生萧飒国宝时光车午后的月光舟离江我与我相惜愚人自欺国韵芸边中玉玲龙海香磊森梦杰含涵'
        X=random.choice(xing)
        M="".join( random.choice(ming) for i in range(random.choice(range(1,4))))
        name = X+M
        return name
 


# -*- coding:utf-8 -*-
import configparser
class config():
    def __init__(self):
        self.config = configparser.ConfigParser()

    def read(self, file, encoding='GB18030'):
        return self.config.read(file, encoding)
     # -sections得到所有的section，并以列表的形式返回

    def sections(self):
        return self.config.sections()

    # -options(section)得到该section的所有option
    def options(self, section):
        return self.config.options(section)
    # 得到该section的所有键值对
    def options(self, section):
        return self.config.items(section)

    #返回为string类型
    def get(self, section, key):
        return self.config.get(section, key)

    def getint(self, section, key):
        return self.config.getint(section, key)

    def getfloat(self, section, key):
        return self.config.getfloat(section, key)

    def getboolean(self, section, key):
        return self.config.getboolean(section, key)



from concurrent.futures import ThreadPoolExecutor, wait
from threading import Lock
from requests import get, head
lock = Lock()

class downloader():
    def __init__(self, url, nums, file):
        self.url = url
        self.num = nums
        self.name = file
        r = head(self.url)
        # 若资源显示302,则迭代找寻源文件
        while r.status_code == 302:
            self.url = r.headers['Location']
            print("该url已重定向至{}".format(self.url))
            r = head(self.url)
        self.size = int(r.headers['Content-Length'])
        print('该文件大小为：{} bytes'.format(self.size))

    def down(self, start, end):
        headers = {'Range': 'bytes={}-{}'.format(start, end)}
        # stream = True 下载的数据不会保存在内存中
        r = get(self.url, headers=headers, stream=True)
        # 写入文件对应位置,加入文件锁
        lock.acquire()
        with open(self.name, "rb+") as fp:
            fp.seek(start)
            fp.write(r.content)
            lock.release()
            # 释放锁

    def run(self):
        # 创建一个和要下载文件一样大小的文件
        fp = open(self.name, "wb")
        fp.truncate(self.size)
        fp.close()
        # 启动多线程写文件
        part = self.size // self.num
        pool = ThreadPoolExecutor(max_workers=self.num)
        futures = []
        for i in range(self.num):
            start = part * i
            # 最后一块
            if i == self.num - 1:
                end = self.size
            else:
                end = start + part - 1
                print('{}->{}'.format(start, end))
            futures.append(pool.submit(self.down, start, end))
        wait(futures)
        print('%s 下载完成' % self.name)

# ss =  Downloader('https://upload.wikimedia.org/wikipedia/commons/thumb/7/79/AL_postcode_area_map.svg/400px-AL_postcode_area_map.svg.png',6, "d6.png")
# ss.run()


#coding=UTF-8
#模拟浏览器自动登录yahoo邮箱
from selenium import webdriver
from time import sleep
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.action_chains import ActionChains
import os
import platform
#一下三行为无头模式运行，无头模式不开启浏览器，也就是在程序里面运行的
# #如果不用上面三行，那么就用下面这一行。运行的时候回自动的开启浏览器，并在浏览器中自动运行，你可以看到自动运行的过程


class chorme():
       def init(self,chrome_options):
              if platform.system() == "Linux":
                     chrome_options.add_argument("--headless")
                     self.driver = webdriver.Chrome(executable_path=('/usr/bin/chromedriver'), options=chrome_options)
              else:              
                     self.driver = webdriver.Chrome(executable_path=(os.getcwd()+'/chromedriver.exe'), options=chrome_options)
       def mobile(self):
              mobile_emulation = {'deviceName': 'iPhone 6 Plus'}
              chrome_options = webdriver.ChromeOptions()
              chrome_options.add_experimental_option("mobileEmulation", mobile_emulation)
              chrome_options.add_argument('--no-sandbox')
              chrome_options.add_argument('--disable-gpu')
              chrome_options.add_argument('--disable-dev-shm-usage')
              self.init(chrome_options)
              return self.driver
       def pc(self):
              chrome_options = webdriver.ChromeOptions()
              chrome_options.add_argument('--no-sandbox')
              chrome_options.add_argument('--disable-gpu')
              chrome_options.add_argument('--disable-dev-shm-usage')
              self.init(chrome_options)
              return self.driver
       # 打开链接
       def get(self, url):
          try:
       #      self.driver.set_page_load_timeout(10)
       #      self.driver.set_script_timeout(10)
            self.driver.get(url)
          except:
            print("timeout")
       #      self.driver.execute_script("window.stop()")
       # 获取内容      
       def getsrouce(self):
             return self.driver.page_source
       # 截图
       def get_screenshot_as_file(self,filename):
              self.driver.get_screenshot_as_file(filename)
       # 获取COOKIE
       def get_cookies(self):
              return self.driver.get_cookies()
       # 退出
       def quit(self):
              self.driver.quit()  
       # 关闭            
       def close(self):
              self.driver.close()              
       # 鼠标悬停
       def hover(self,by,value):
              element = self.findElement(by,value)
              ActionChains(self.driver).move_to_element(element).perform()
       # 鼠标点击      
       def click(self,by,value):
              element = self.findElement(by,value)
              ActionChains(self.driver).click(element).perform()
       #输入内容
       def send_keys(self,by,value,keys):
              element = self.findElement(by,value)
              ActionChains(self.driver).send_keys(keys).perform()

       # 通过不同的方式查找界面元素
       def findElement(self,by,value):
              if(by == "id"):
                     element = self.driver.find_element_by_id(value)
                     return element
              elif(by == "name"):
                     element = self.driver.find_element_by_name(value)
                     return element
              elif(by == "xpath"):
                     element = self.driver.find_element_by_xpath(value)
                     return element
              elif(by == "classname"):
                     element = self.driver.find_element_by_class_name(value)
                     return element
              elif(by == "css"):
                     element = self.driver.find_element_by_css_selector(value)
                     return element
              elif(by == "link_text"):
                     element = self.driver.find_element_by_link_text(value)
                     return element
              else:
                     print("无对应方法，请检查")
                     return None


# XPATH方式详解
# 表达式	结果
# //*[count(xxx)=2]	统计xxx元素个数=2的节点
# //*[local-name()='xxx']	找到tag为xxx的元素
# //*[starts-with(local-name(),'x')]	找到所有tag以x开头的元素
# //*[contains(local-name(),'x')]	找到所有tag包含x的元素
# //*[string-length(local-name())=3]	找到所有tag长度为3的元素
# //xxx丨//yyy
# ————————————————
# 属性	实例
# id属性	find_element_by_xpath("//input[@id='kw']")
# class属性	element_by_xpath("//input[@class='s_ipt']")
# name属性	find_element_by_xpath("//input[@name='wd']")
# maxlength属性	find_element_by_xpath("//input[@maxlength='255']")
# ————————————————


# 模拟键盘输入和按键
# from selenium.webdriver.common.keys import Keys
# click(on_element=None)                 #鼠标左键单击
# click_and_hold(on_element=None)        #单击鼠标左键，不松开
# context_click(on_element=None)         #单击鼠标右键
# double_click(on_element=None)          #双击鼠标左键
# drag_and_drop(source,target)           #拖拽到某个元素然后松开
# drag_and_drop_by_offset(source,xoffset,yoffset) #拖拽到某个坐标然后松开
# key_down(value,element=None)     #按下键盘上的某个键
# key_up(value, element=None)      #松开键盘上的某个键
# move_by_offset(xoffset, yoffset)  #鼠标从当前位置移动到某个坐标
# move_to_element(to_element)        #鼠标移动到某个元素
# move_to_element_with_offset(to_element, xoffset, yoffset) #移动到距某个元素（左上角坐标）多少距离的位置
# pause(seconds)                  #暂停所有输入(指定持续时间以秒为单位)
# perform()                       #执行所有操作
# reset_actions()                 #结束已经存在的操作并重置
# release(on_element=None)       #在某个元素位置松开鼠标左键
# send_keys(*keys_to_send)        #发送某个键或者输入文本到当前焦点的元素
# send_keys_to_element(element, *keys_to_send) #发送某个键到指定元素

# 元素操作
# kw1.clear()        #清除元素的值
# kw1.click()        #点击元素
# kw1.id             #Selenium所使用的内部ID
# kw1.get_property('background') #获取元素的属性的值
# kw1.get_attribute('id') #获取元素的属性的值
# kw1.location       #不滚动获取元素的坐标
# kw1.location_once_scrolled_into_view  #不滚动且底部对齐并获取元素的坐标
# kw1.parent         #父元素
# kw1.send_keys('')  #向元素内输入值
# kw1.size           #大小
# kw1.submit         #提交
# kw1.screenshot('2.png') #截取元素形状并保存为图片
# kw1.tag_name       #标签名
# kw1.text           #内容，如果是表单元素则无法获取
# kw1.is_selected()  #判断元素是否被选中
# kw1.is_enabled()   #判断元素是否可编辑
# kw1.is_displayed   #判断元素是否显示
# kw1.value_of_css_property('color') #获取元素属性的值
# kw1._upload('2.png') #上传文件

# 浏览器参数
# o.add_argument('--window-size=600,600') #设置窗口大小
# o.add_argument('--incognito') #无痕模式
# o.add_argument('--disable-infobars') #去掉chrome正受到自动测试软件的控制的提示
# o.add_argument('user-agent="XXXX"') #添加请求头
# o.add_argument("--proxy-server=http://200.130.123.43:3456")#代理服务器访问
# o.add_experimental_option('excludeSwitches', ['enable-automation'])#开发者模式
# o.add_experimental_option("prefs",{"profile.managed_default_content_settings.images": 2})#禁止加载图片
# o.add_experimental_option('prefs',
# {'profile.default_content_setting_values':{'notifications':2}}) #禁用浏览器弹窗
# o.add_argument('blink-settings=imagesEnabled=false')  #禁止加载图片
# o.add_argument('lang=zh_CN.UTF-8') #设置默认编码为utf-8
# o.add_extension(create_proxyauth_extension(
#            proxy_host='host',
#            proxy_port='port',
#            proxy_username="username",
#            proxy_password="password"
#        ))# 设置有账号密码的代理
# o.add_argument('--disable-gpu')  # 这个属性可以规避谷歌的部分bug
# o.add_argument('--disable-javascript')  # 禁用javascript
# o.add_argument('--hide-scrollbars')  # 隐藏滚动条
# o.binary_location=r"C:\Users\Administrator\AppData\Local\Google\Chrome\Application" #指定浏览器位置
# o.add_argument('--no-sandbox')  #解决DevToolsActivePort文件不存在的报错

# https://blog.csdn.net/qq_44326412/article/details/107825851



from setuptools import setup, find_packages
setup(
    name="gather_tools",
    packages=find_packages(),
    version='1.2.3',
    description="Gather Tools",
    author="Merreel",
    long_description=open('README.md',encoding="utf-8").read(),
    author_email='1327444968@qq.com',
    # url="https://github.com/username/reponame",
    # download_url='https://github.com/username/reponame/archive/0.1.tar.gz',
    keywords=['command', 'line', 'tool'],
    classifiers=[],
    # entry_points={
    #     'console_scripts': [
    #     'command1 = gather_tools.cmdline:execute'
    # ]
    # },
    install_requires=[
        'selenium',
        'requests',
    ]
)